Lightning BOLT11 utils
======================

[![travis-badge]][travis]
[![codecov-badge]][codecov]
[![pypi-badge]][pypi]
[![pypi-versions]][pypi]
[![license-badge]](LICENSE)

This is an implementation of Lightning BOLT11 Specification, based on [Rusty Russell's work][rusty]
and packaged as a standalone library that can be used by other projects. 

[travis]: https://travis-ci.com/python-ln/bolt11?branch=master
[travis-badge]: https://api.travis-ci.com/python-ln/bolt11.svg?branch=master
[codecov]: https://codecov.io/gh/python-ln/bolt11
[codecov-badge]: https://codecov.io/gh/python-ln/bolt11/branch/master/graph/badge.svg
[pypi]: https://pypi.org/project/bolt11/
[pypi-badge]: https://badge.fury.io/py/bolt11.svg
[pypi-versions]: https://img.shields.io/pypi/pyversions/bolt11.svg
[license-badge]: https://img.shields.io/badge/license-MIT-blue.svg

[rusty]: https://github.com/rustyrussell/lightning-payencode
